@@ -1,10 +1,10 @@
+import json
 import re
 import traceback
 from os.path import join
 from pathlib import Path
 from sys import stdout
 from typing import Union
-import json
 
 import yaml
 from friendlylog import colored_logger as log
@@ -32,6 +32,7 @@ class Evaluator():
                 args = {}
                 if arg_match:
                     arg_str = arg_match.group(1).strip()
+                    arg_str = self.__replace_vars(arg_str, context)
                     # print('---')
                     # print('--arg_str--', arg_str)
                     # print('---')
@@ -68,7 +69,8 @@ class Evaluator():
                     expr = re.sub(
                         f"\\${var}", f"{dotpath_get_value(context['fields'], var)}{' (' + var + ')' if informative else ''}", expr)
                 else:
-                    log.warning(f"'{var}' is not defined.")
+                    log.warning(
+                        f"Variable '{var}' is not defined, used in expression '{expr}'.")
                     expr = re.sub(f"\\${var}", 'None', expr)
         return expr
 
@@ -116,9 +118,9 @@ class Evaluator():
                         evaluation += ')'
                     else:
                         evaluation += f" {op} "
-                # # print(evaluation)
-                # # print(self.__replace_vars(evaluation, context))
-                # # print(self.__replace_functions(evaluation, context))
+                # print(evaluation)
+                # print(self.__replace_vars(evaluation, context))
+                # print(self.__replace_functions(evaluation, context))
             else:
                 raise Exception(
                     "Only 'and' and 'or' are allowed operators.", condition)
@@ -130,6 +132,7 @@ class Evaluator():
         """
         A condition is always True or False
         """
+        # print('--condition--', condition)
         if isinstance(condition, bool):
             return condition
         if isinstance(condition, str):
@@ -139,11 +142,11 @@ class Evaluator():
             try:
                 result = eval(condition)
             except Exception as ex:
-                log.waring(ex)
+                log.warning(f"Cannot evaluate condition '{condition}': {ex}")
             finally:
+                # print('--result--', condition)
                 return result
         elif isinstance(condition, list):
-            # print('--initial condition--', condition)
             return self.__eval_and_or(condition, context)
 
     def __evaluate_variables(self, _vars: dict, obj: dict, context: dict):
@@ -225,6 +228,7 @@ class Evaluator():
             log.debug(f"{key}: {val}")
 
     def __get_evaluation(self, evaluation, context):
+
         return json.loads(self.__replace_vars(
             json.dumps(evaluation), context, informative=True))
 
